@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: hakyll
 version: 4.7.5.1
-id: hakyll-4.7.5.1-378313a4bda08c68789ba8bf5e35c93d
-key: hakyl_61oDvASVaUwCRjAZ3CwJXx
+id: hakyll-4.7.5.1-ad3312425ae839ad9e85eef9a1764729
+key: hakyl_6sWjbEMvR5kDaSTa9mo5ud
 license: BSD3
 maintainer: Jasper Van der Jeugt <m@jaspervdj.be>
 homepage: http://jaspervdj.be/hakyll
@@ -50,12 +50,12 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/hakyll-4.7.5.1
 library-dirs: /usr/lib/ghc-7.10.3/site-local/hakyll-4.7.5.1
 data-dir: /usr/share/arm-linux-ghc-7.10.3/hakyll-4.7.5.1
-hs-libraries: HShakyll-4.7.5.1-61oDvASVaUwCRjAZ3CwJXx
+hs-libraries: HShakyll-4.7.5.1-6sWjbEMvR5kDaSTa9mo5ud
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     binary-0.7.5.0-29f7044fa0b12dc5c2dcec897db5c464
-    blaze-html-0.8.1.1-59ea4b5f01886f370857b4d16361c2fc
-    blaze-markup-0.7.0.3-4e4a97653c712eed9984271000636729
+    blaze-html-0.8.1.1-1d54daeba5477a1aa0462b832a558865
+    blaze-markup-0.7.0.3-fed4a147945def017f9ea9594b30666a
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
     cmdargs-0.10.14-ea4d1877c8c5fa6ed8eebd52f962ac3b
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
@@ -64,21 +64,21 @@ depends:
     deepseq-1.4.1.1-3975618f889b45239daa47b7443eaeee
     directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
     filepath-1.4.0.0-73e0bec80594160bf6dd6cb25217c6bf
-    http-conduit-2.1.8-3cbd23ba75c7bf6ee8e4c2285c87f4dc
-    http-types-0.9-181a315082d46c3ed5dffe75933f2447
-    lrucache-1.2.0.0-97fd799690b7e95999ded6be87e87c88
+    http-conduit-2.1.8-0cd87eafc953cbe4f675bdf50a2df8e2
+    http-types-0.9-a274b17bf4f057225e6c0af6d57f03ec
+    lrucache-1.2.0.0-ceecb0f943a41257c9253e3896a3e896
     mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
     network-2.6.2.1-602ee4a12c5a174f6683a75303a065d3
-    network-uri-2.6.0.3-27316eb865f3b3562ae77903534d67a4
-    pandoc-1.16.0.2-31f468e05a5caa86237ccb0bcb6308ba
-    pandoc-citeproc-0.9-1d62a0bc83cc5a76018a3fc21732faa7
-    parsec-3.1.9-e73195cf6af19ee9d1587f67fa792c42
+    network-uri-2.6.1.0-0e39aca8530572505c01ef548c540bd6
+    pandoc-1.17.0.1-1c6da1ddfcd8a2619fb2ca103a269dd9
+    pandoc-citeproc-0.9.1.1-e33a750d478d5c454d26592c51122195
+    parsec-3.1.9-3365ddffd9ca11d2f0b377e002b54baf
     process-1.2.3.0-21d25f1d78aeea6e68f1c768841f9794
     random-1.1-41a0a7ecd483c665a5c3a093a5be2968
     regex-base-0.93.2-42cdf19dc92d6af642a96da5984c8c2c
-    regex-tdfa-1.2.1-2f2ff40a952b63109ef37be1ffea97d0
-    tagsoup-0.13.9-50d5019a7872f558763ae9548d877c82
-    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
+    regex-tdfa-1.2.1-506e9a407febb132e40b4c629d403ead
+    tagsoup-0.13.9-61f7129b459feb0b7d9b7f0c4b3300d3
+    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
     time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
     time-locale-compat-0.1.1.1-4bbdeebce90c671369911a4d16cfee44
 haddock-interfaces: /usr/share/doc/haskell-hakyll/html/hakyll.haddock
